package com.ruoyi.shipping.domain;

import lombok.Data;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;

import java.math.BigDecimal;
import java.util.List;

/**
 * 集装箱对象 t_cntr
 * 
 * @author ruoyi
 * @date 2021-03-22
 */
@Data
public class TCntr extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long fId;

    /** 集装箱类型（1 普柜 2 冻柜） */
    @Excel(name = "集装箱类型", readConverterExp = "1=,普=柜,2=,冻=柜")
    private Integer fType;

    /** 编号 */
    @Excel(name = "编号")
    private String fNo;

    /** 名称 */
    @Excel(name = "名称")
    private String fName;

    /** 英文名称 */
    @Excel(name = "英文名称")
    private String fEname;

    /** uncode */
    @Excel(name = "uncode")
    private String fUncode;

    /** TEU */
    @Excel(name = "TEU")
    private BigDecimal fTeu;

    /** 箱容量（立方） */
    @Excel(name = "箱容量", readConverterExp = "立=方")
    private BigDecimal fCbm;

    /** 箱容量（吨） */
    @Excel(name = "箱容量", readConverterExp = "吨=")
    private BigDecimal fWeight;

    /** 尺码 （20 40 45） */
    @Excel(name = "尺码 ", readConverterExp = "2=0,4=0,4=5")
    private BigDecimal fCntrsize;

    /** 状态（默认 T ,正常T 停用F 下拉选择） */
    @Excel(name = "状态", readConverterExp = "默=认,T=,,=正常T,停=用F,下=拉选择")
    private String fStatus;

    public Long getfId() {
        return fId;
    }

    public void setfId(Long fId) {
        this.fId = fId;
    }

    public Integer getfType() {
        return fType;
    }

    public void setfType(Integer fType) {
        this.fType = fType;
    }

    public String getfNo() {
        return fNo;
    }

    public void setfNo(String fNo) {
        this.fNo = fNo;
    }

    public String getfName() {
        return fName;
    }

    public void setfName(String fName) {
        this.fName = fName;
    }

    public String getfEname() {
        return fEname;
    }

    public void setfEname(String fEname) {
        this.fEname = fEname;
    }

    public String getfUncode() {
        return fUncode;
    }

    public void setfUncode(String fUncode) {
        this.fUncode = fUncode;
    }

    public BigDecimal getfTeu() {
        return fTeu;
    }

    public void setfTeu(BigDecimal fTeu) {
        this.fTeu = fTeu;
    }

    public BigDecimal getfCbm() {
        return fCbm;
    }

    public void setfCbm(BigDecimal fCbm) {
        this.fCbm = fCbm;
    }

    public BigDecimal getfWeight() {
        return fWeight;
    }

    public void setfWeight(BigDecimal fWeight) {
        this.fWeight = fWeight;
    }

    public BigDecimal getfCntrsize() {
        return fCntrsize;
    }

    public void setfCntrsize(BigDecimal fCntrsize) {
        this.fCntrsize = fCntrsize;
    }

    public String getfStatus() {
        return fStatus;
    }

    public void setfStatus(String fStatus) {
        this.fStatus = fStatus;
    }

    public List<String> getcLoadDate() {
        return cLoadDate;
    }

    public void setcLoadDate(List<String> cLoadDate) {
        this.cLoadDate = cLoadDate;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }


    //查询时间区间
    private List<String> cLoadDate;
    //箱柜类型
    private String typeName;



}
